Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2012-09-07 20:06:58 +0400
committerBastien Montagne <montagne29@wanadoo.fr>2012-09-07 20:06:58 +0400
commit8367c79f6969a4d388292244e189eff675c22202 (patch)
treeb70565eb35199f16ac9788b67af7dc0d3dd4bbfb /source
parent86251329d0db4c331ecee144599b9cf5790dc310 (diff)
Adding Hebrew language.
Note: looks like we do not have hebrew chars in current font... More FontForge fun ahead. :/
Diffstat (limited to 'source')
-rw-r--r--source/blender/blenfont/intern/blf_lang.c1
-rw-r--r--source/blender/makesrna/intern/rna_userdef.c3
2 files changed, 3 insertions, 1 deletions
diff --git a/source/blender/blenfont/intern/blf_lang.c b/source/blender/blenfont/intern/blf_lang.c
index 55a65f07759..2b7e225d709 100644
--- a/source/blender/blenfont/intern/blf_lang.c
+++ b/source/blender/blenfont/intern/blf_lang.c
@@ -108,6 +108,7 @@ static const char *locales[] = {
"turkish", "tr_TR",
"hungarian", "hu_HU",
"brazilian portuguese", "pt_BR",
+ "hebrew", "he_IL",
};
void BLF_lang_init(void)
diff --git a/source/blender/makesrna/intern/rna_userdef.c b/source/blender/makesrna/intern/rna_userdef.c
index f753ff680fd..7f8c6951620 100644
--- a/source/blender/makesrna/intern/rna_userdef.c
+++ b/source/blender/makesrna/intern/rna_userdef.c
@@ -2982,7 +2982,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* locale according to http://www.roseindia.net/tutorials/I18N/locales-list.shtml */
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
* here is the highest define currently in use: 32 (Brazilian Portuguese). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, N_("Nearly done"), ""},
{ 0, "DEFAULT", 0, "Default (Default)", ""},
@@ -3008,6 +3008,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
{ 6, "FINNISH", 0, "Finnish (Suomi)", "fi_FI"},
{ 5, "GERMAN", 0, "German (Deutsch)", "de_DE"},
{23, "GREEK", 0, "Greek (Ελληνικά)", "el_GR"},
+ {33, "HEBREW", 0, "Hebrew (עִבְרִית)", "he_IL"},
{31, "HUNGARIAN", 0, "Hungarian (magyar)", "hu_HU"},
{27, "INDONESIAN", 0, "Indonesian (Bahasa indonesia)", "id_ID"},
{29, "KYRGYZ", 0, "Kyrgyz (Кыргыз тили)", "ky_KG"},
@@ -2982,7 +2982,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
- * here is the highest define currently in use: 32 (Brazilian Portuguese). */
+ * here is the highest define currently in use: 33 (Hebrew). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, N_("Nearly done"), ""},